summaryrefslogtreecommitdiffhomepage
path: root/packages/browser/src/methods/startAssertion.ts
diff options
context:
space:
mode:
Diffstat (limited to 'packages/browser/src/methods/startAssertion.ts')
-rw-r--r--packages/browser/src/methods/startAssertion.ts4
1 files changed, 2 insertions, 2 deletions
diff --git a/packages/browser/src/methods/startAssertion.ts b/packages/browser/src/methods/startAssertion.ts
index 826763a..0648e56 100644
--- a/packages/browser/src/methods/startAssertion.ts
+++ b/packages/browser/src/methods/startAssertion.ts
@@ -2,7 +2,7 @@ import {
PublicKeyCredentialRequestOptionsJSON,
AuthenticatorAssertionResponseJSON,
AssertionCredential,
-} from '@webauthntine/typescript-types';
+} from '@simplewebauthn/typescript-types';
import toUint8Array from '../helpers/toUint8Array';
import toBase64String from '../helpers/toBase64String';
@@ -12,7 +12,7 @@ import toPublicKeyCredentialDescriptor from '../helpers/toPublicKeyCredentialDes
/**
* Begin authenticator "login" via WebAuthn assertion
*
* @param requestOptionsJSON Output from @webauthntine/server's generateAssertionOptions(...)
*/
export default async function startAssertion(
requestOptionsJSON: PublicKeyCredentialRequestOptionsJSON,
@@ -12,7 +12,7 @@ import toPublicKeyCredentialDescriptor from '../helpers/toPublicKeyCredentialDes
* Begin authenticator "login" via WebAuthn assertion
*
- * @param requestOptionsJSON Output from @webauthntine/server's generateAssertionOptions(...)
+ * @param requestOptionsJSON Output from @simplewebauthn/server's generateAssertionOptions(...)
*/
export default async function startAssertion(